Elevator constructor

const Elevator({
  1. required Widget builder(
    1. bool elevated
    ),
  2. Key? key,
  3. bool dismissOnTap = true,
})

Creates a new Elevator widget.

The builder function is called with a boolean indicating whether the widget is currently elevated, allowing you to modify the appearance based on the elevation state.

Implementation

const Elevator({required this.builder, super.key, this.dismissOnTap = true});