dismissOnTap property

bool dismissOnTap
final

Whether the elevated state should be dismissed when tapping on the overlay.

When true, tapping on the elevated overlay will cause it to return to its non-elevated state. Defaults to true.

Implementation

final bool dismissOnTap;