Elevator constructor
Creates a new Elevator widget.
The builder function is called with a boolean indicating whether the
widget is currently elevated, allowing you to modify the appearance based
on the elevation state.
Implementation
const Elevator({required this.builder, super.key, this.dismissOnTap = true});